common_features: Finds common features in a list of cds objects

View source: R/utils.R

common_featuresR Documentation

Finds common features in a list of cds objects

Description

Machine learning algorithms often require features to be the same across datasets. Thisfunction finds common features between a list of cell data set objects and returns a list of cds's that have the same features. Note that this function uses rownames of the 'fData' DataFrame to find the intersect of features common to all cds's

Usage

common_features(cds_list)

Arguments

cds_list

Input cell_data_set object.


scfurl/viewmaster documentation built on Nov. 22, 2022, 2:59 p.m.